@@ -33,6 +33,11 @@ BayonneSession *BayonneBinder::session(ScriptInterp *s)
 	return (BayonneSession *)(s);
 }
 
+const char *BayonneBinder::submit(const char **args)
+{
+	return NULL;
+}
+
 bool BayonneBinder::scriptEvent(ScriptInterp *interp, const char *evt)
 {
 	return (session(interp))->stringEvent(evt);
@@ -43,14 +48,10 @@ bool BayonneBinder::digitEvent(ScriptInterp *interp, const char *evt)
 	return (session(interp))->digitEvent(evt);
 }
 
-Script::Name *BayonneBinder::getService(ScriptImage *img, ScriptInterp *interp, const char *sid)
+const char *BayonneBinder::submitRequest(const char **args)
 {
-	return binder->service(img, interp, sid);
-}
-
-Script::Name *BayonneBinder::service(ScriptImage *img, ScriptInterp *interp, const char *sid)
-{
-	return NULL;
+	return binder->submit(args);
 }
 
 
+
