@@ -26,7 +26,7 @@ BayonneDriver *BayonneDriver::trunkDriver = NULL;
 BayonneDriver *BayonneDriver::protoDriver = NULL;
 Semaphore BayonneDriver::oink(0);
 
-BayonneDriver::BayonneDriver(Keydata::Define *pairs, const char *cfg, const char *id, bool pri) :
+BayonneDriver::BayonneDriver(Keydata::Define *pairs, const char *cfg, const char *id, bool virt) :
 Keydata(pairs, getKeypath(cfg)), Mutex()
 {
 	name = id;
@@ -80,16 +80,7 @@ BayonneDriver::~BayonneDriver()
 
 unsigned BayonneDriver::getRegistration(regauth_t *data, unsigned count)
 {
-	return 0;
-}
-
-const char *BayonneDriver::remapDriver(const char *id)
-{
-#ifndef	WIN32
-	if(!stricmp(id, "sip"))
-		return NAME_SIP_DRIVER;
-#endif
-	return id;
+        return 0;
 }
 
 void BayonneDriver::del(BayonneSession *session)
@@ -270,9 +261,9 @@ BayonneDriver *BayonneDriver::loadDriver(const char *id)
 	char prefixbuf[256];
 	if(!prefix && provision_test)
 	{
-		snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s/.libs", SOURCE_FILES, remapDriver(id));
+		snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s/.libs", SOURCE_FILES, id);
 		if(!isDir(prefixbuf))
-			snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s", SOURCE_FILES, remapDriver(id));
+			snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s", SOURCE_FILES, id);
 		prefix = prefixbuf;
 	}
 #endif
@@ -293,7 +284,7 @@ BayonneDriver *BayonneDriver::loadDriver(const char *id)
 
 	if(!canAccess(path))
 	{
-		errlog("access", "cannot load driver %s", path);
+		errlog("access", "cannot load %s", path);
 		return NULL;
 	}
 
