@@ -45,6 +45,9 @@ BayonneTranslator::BayonneTranslator(const char *name)
 	first = this;
 }
 
+BayonneTranslator::~BayonneTranslator()
+{}
+
 BayonneTranslator *BayonneTranslator::get(const char *id)
 {
 	BayonneTranslator *bts = first;
