@@ -40,7 +40,10 @@ TimerPort(), Mutex()
 	memset(silent_frame, 0, info.framecount * 2);
 	silent_encoded = new unsigned char[info.framesize];
         if(info.encoding == Audio::pcm16Mono)
+	{
+		info.order = __BIG_ENDIAN;
                 memset(silent_encoded, 0, info.framesize);
+	}
         else if(session->codec)
                 session->codec->encode(silent_frame, silent_encoded, info.framecount);
 
@@ -295,10 +298,10 @@ void RTPStream::peerAudio(Encoded encoded, bool linear)
 	if(linear && session->codec)
 	{
 		session->codec->encode((Linear)encoded, pbuffer, info.framecount);
-		putBuffer(pbuffer, info.framesize);
+		putNative(pbuffer, info.framesize);
 	}
 	else
-		putBuffer(encoded, info.framesize);
+		putNative(encoded, info.framesize);
 }
 
 void RTPStream::run(void)
@@ -394,7 +397,7 @@ void RTPStream::run(void)
 			if(codec)
 			{
 				codec->encode(tbuf, buffer, info.framecount);
-				putBuffer(buffer, size);
+				putNative(buffer, size);
 				silent = false;
 			}				
 			if(jsend)
@@ -419,7 +422,7 @@ void RTPStream::run(void)
 					ending = false;
 				}
 				silent = false;
-	                        putBuffer(buffer, size);
+	                        putNative(buffer, size);
 			}
 			else if(!ending)
 			{
@@ -445,7 +448,7 @@ done:
 		if(silent && Driver::sip.data_filler)
 		{
 			silent = false;
-			putBuffer(silent_encoded, info.framesize);
+			putNative(silent_encoded, info.framesize);
 		}
 
 		r = dispatchDataPacket();
@@ -485,7 +488,7 @@ done:
 				first = false;
 
 	                        enter();
-        	                n = getBuffer(buffer, r);
+        	                n = getNative(buffer, r);
 				if(dtmf && codec && n == size && session->dtmf)
 				{
 					codec->decode(lbuffer, buffer, info.framecount);
@@ -510,7 +513,7 @@ done:
 
 				Thread::yield();
 				enter();
-				n = getBuffer(buffer, r);
+				n = getNative(buffer, r);
 				if(dtmf && codec && n == size && session->dtmf)
 				{
 					codec->decode(lbuffer, buffer, info.framecount);
