@@ -39,14 +39,11 @@ class Session : public TCPSession, public Bayonne
 private:
 	char *monmap;
 
-	void startDriver(BayonneDriver *d, const char *scr, const char *dial, const char *caller, const char *display);
-	void startSelect(const char *scr, const char *dial, const char *caller, const char *display);
 	void help(void);
-	void paths(void);
-	void reg(BayonneDriver *d);
 	void calls(char **list);
 	void allcalls(void);
 	void spans(void);
+	void reg(void);
 	void monitor(char **list);
 	void nomon(char **list);
 	void drivers(char **list);
