@@ -89,10 +89,10 @@ void Session::uptime(void)
 	char dur[12];
 
 	if(upt < 100 * 3600)
-		snprintf(dur, sizeof(dur), "%02d:%02d:%02d",
+		snprintf(dur, sizeof(dur), "%02ld:%02ld:%02ld",
 			upt / 3600, (upt / 60) % 60, upt % 60);
 	else
-		snprintf(dur, sizeof(dur), "%d days", upt / (3600 * 24));	
+		snprintf(dur, sizeof(dur), "%ld days", upt / (3600 * 24));	
 	
 	*tcp() << "uptime: " << dur << endl;
 }
