@@ -17,6 +17,13 @@
 #include "driver.h"
 #include <cc++/process.h>
 
+#ifdef  WIN32
+#define CONFIG_FILES    "C:/Program Files/GNU Telephony/Bayonne Config"
+#define strdup  ost::strdup
+#else
+#include <private.h>
+#endif
+
 namespace vpbdriver {
 using namespace ost;
 using namespace std;
@@ -40,7 +47,7 @@ static Keydata::Define driver[] = {
 Driver Driver::voicetronix;
 
 Driver::Driver() :
-BayonneDriver(driver, KEYS, "voicetronix", true),
+BayonneDriver(driver, KEYS, "voicetronix", false),
 Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 {
 	const char *cp;
@@ -102,6 +109,10 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 
 	if(peer_framing == 0)
 		peer_framing = Audio::getFraming(peer_encoding, 20);
+
+	server->setValue("trunk.conf", CONFIG_FILES "/trunk.conf");
+	server->setValue("timeslot.conf", CONFIG_FILES "/timeslot.conf");
+	server->setValue("caller.conf", CONFIG_FILES "/caller.conf");
 }
 
 void Driver::startDriver(void)
