@@ -567,8 +567,6 @@ bool parseConfig(char **argv)
 	char *argv0 = *(argv++);
 	char *ext;
 	unsigned scrcount = 0;
-	unsigned minslots = 0;
-	bool live = true;
 
 #ifndef	WIN32
 	const char *cp;
